@@ -2,8 +2,8 @@ from cloud_info_provider.collectors import base
 
 
 class CloudCollector(base.BaseCollector):
-    def __init__(self, opts, providers):
-        super(CloudCollector, self).__init__(opts, providers)
+    def __init__(self, *args):
+        super(CloudCollector, self).__init__(*args)
         self.templates = ('headers', 'clouddomain')
 
     def fetch(self):
