@@ -36,6 +36,54 @@ class OpenStackProviderOptionsTest(base.TestCase):
         self.assertEqual(opts.select_flavors, 'public')
 
 
+class OpenStackProviderAuthTest(base.TestCase):
+
+    # Do not limit diff output on failures
+    maxDiff = None
+
+    def setUp(self):
+        super(OpenStackProviderAuthTest, self).setUp()
+
+        class FakeProvider(os_provider.OpenStackProvider):
+            def __init__(self, opts):
+                self.project_id = None
+                self.opts = mock.Mock()
+
+        self.provider = FakeProvider(None)
+
+    def test_rescope_simple(self):
+        self.provider.auth_refresher = None
+        with utils.nested(
+                mock.patch('keystoneauth1.loading.'
+                           'load_auth_from_argparse_arguments'),
+                mock.patch('keystoneauth1.loading.'
+                           'load_session_from_argparse_arguments')
+        ) as (_, m_load_session):
+            session = mock.Mock()
+            session.get_project_id.return_value = 'foo'
+            m_load_session.return_value = session
+            self.provider._rescope_project('foo', 'bar')
+            self.assertEqual('foo', self.provider.project_id)
+
+    def test_rescope_refresh(self):
+        m_refresh = mock.Mock()
+        self.provider.auth_refresher = mock.Mock()
+        self.provider.auth_refresher.refresh = m_refresh
+        with utils.nested(
+                mock.patch('keystoneauth1.loading.'
+                           'load_auth_from_argparse_arguments'),
+                mock.patch('keystoneauth1.loading.'
+                           'load_session_from_argparse_arguments'),
+        ) as (_, m_load_session):
+            session = mock.Mock()
+            session.get_project_id.return_value = 'foo'
+            m_load_session.return_value = session
+            self.provider._rescope_project('foo', 'bar')
+            self.assertEqual('foo', self.provider.project_id)
+            m_refresh.assert_called_with(self.provider, project_id='foo',
+                                         vo='bar')
+
+
 class OpenStackProviderTest(base.TestCase):
 
     # Do not limit diff output on failures
@@ -647,6 +695,46 @@ class OpenStackProviderTest(base.TestCase):
     def test_service_type(self):
         self.assertEqual('compute', self.provider.service_type)
 
+    def test_get_instances(self):
+
+        class FakeInstance(object):
+            def __init__(self, name, image, flavor, status):
+                self.id = self.name = name
+                self.image = image
+                self.flavor = flavor
+                self.status = status
+
+        expected_instances = {
+            'foo': {
+                'instance_name': 'foo',
+                'instance_image_id': '',
+                'instance_template_id': '123',
+                'instance_status': 'RUNNING',
+            },
+            'baz': {
+                'instance_name': 'baz',
+                'instance_image_id': 'bar',
+                'instance_template_id': '456',
+                'instance_status': 'RUNNING',
+            },
+            'foobar': {
+                'instance_name': 'foobar',
+                'instance_image_id': '',
+                'instance_template_id': '',
+                'instance_status': 'SUSPENDED',
+            },
+        }
+
+        with mock.patch.object(self.provider.nova.servers, 'list') as m_list:
+            m_list.return_value = [
+                FakeInstance('foo', '', {'id': '123'}, 'RUNNING'),
+                FakeInstance('baz', {'id': 'bar'}, {'id': '456'}, 'RUNNING'),
+                FakeInstance('foobar', '', {}, 'SUSPENDED'),
+            ]
+            kwargs = {'auth': {'project_id': None}}
+            instances = self.provider.get_instances(**kwargs)
+            self.assertEqual(expected_instances, instances)
+
 
 class OoiProviderTest(OpenStackProviderTest):
     def setUp(self):
